@@ -46,7 +46,6 @@ class FLEBasis2D:
             numsparse = 8
             maxitr = 1 + int(np.log2(L)) // 2
 
-
         self.W = self.precomp(
             L,
             bandlimit,
@@ -65,6 +64,11 @@ class FLEBasis2D:
         maxfun=None,
     ):
 
+        # ORIGINAL DIMENSIONS
+        self.L1 = L
+        # IF DIMENSIONS ARE ODD ADD ONE (WILL BE PADDING)
+        L = L + (L % 2)
+
         # see {eq:num_radial_nodes}
         # n_radial = int(max(2.1 * L, np.log2(1 / eps)))
 
@@ -88,7 +92,7 @@ class FLEBasis2D:
         if maxfun:
             ne = maxfun
         else:
-            ne = int(L**2 * np.pi / 4)
+            ne = int(L ** 2 * np.pi / 4)
 
         max_bandlimit = L
         psi, ns, ks, lmds, cs, ne = self.lap_eig_disk(
@@ -190,7 +194,7 @@ class FLEBasis2D:
         xs, ys = np.meshgrid(x, y)
         xs = xs / R
         ys = ys / R
-        rs = np.sqrt(xs**2 + ys**2)
+        rs = np.sqrt(xs ** 2 + ys ** 2)
 
         idx = rs > 1 + 1e-13
 
@@ -208,7 +212,7 @@ class FLEBasis2D:
             int(lmd1 + ndmax) + 1, S + 1
         ):  # we used s somewhere else, so using svar here
             tmp = (
-                L**2 * ((lmd1 + ndmax) / svar) ** svar
+                L ** 2 * ((lmd1 + ndmax) / svar) ** svar
             )  # ndmax = n_m from the writeup, right?
             if tmp <= eps:
                 n_angular = int(max(int(svar), np.log2(1 / eps)))
@@ -229,14 +233,13 @@ class FLEBasis2D:
             nus[2 * i] = i
         c2r_nus = self.precomp_transform_complex_to_real(nus)
         r2c_nus = spr.csr_matrix(c2r_nus.transpose().conj())
-        
+
         xs = 1 - (2 * np.arange(n_radial) + 1) / (2 * n_radial)
         xs = np.cos(np.pi * xs)
         pts = (xs + 1) / 2
         pts = (lmd1 - lmd0) * pts + lmd0
         pts = pts.reshape(-1, 1)
 
-
         blk_size = np.zeros(2 * nmax + 1)
         for i in range(2 * nmax + 1):
             blk_size[i] = len(idx_list[i])
@@ -252,19 +255,20 @@ class FLEBasis2D:
         ci = 0
         for ell in range(nmax + 1):
             sgns = (1,) if ell == 0 else (1, -1)
-            ks = np.arange(0, k_max[ell])
+            kstmp = np.arange(0, k_max[ell])
 
             for sgn in sgns:
-                rng = np.arange(i, i + len(ks))
+                rng = np.arange(i, i + len(kstmp))
                 indices_ells[rng] = ell
                 indices_sgns[rng] = sgn
 
-                i += len(ks)
-
-            ci += len(ks)
+                i += len(kstmp)
 
+            ci += len(kstmp)
 
+        ind_vec = (nus % 2 - 2) * -np.sign(nus)
 
+        self.ind_vec = ind_vec
         self.indices_sgns = indices_sgns
         self.indices_ells = indices_ells
         self.pts = pts
@@ -304,7 +308,6 @@ class FLEBasis2D:
         if L < 16:
             self.B = self.create_denseB()
 
-
         R = L // 2
         h = 1 / R
         phi = 2 * np.pi * np.arange(self.n_angular // 2) / self.n_angular
@@ -317,6 +320,8 @@ class FLEBasis2D:
         x = x.flatten()
         y = y.flatten()
 
+        self.grid_x = x
+        self.grid_y = y
         nufft_type = 2
         self.plan2 = finufft.Plan(nufft_type, (L, L), n_trans=1, eps=eps)
         self.plan2.setpts(x, y)
@@ -339,7 +344,6 @@ class FLEBasis2D:
             b = idct(b, axis=0, type=2) * 2 * b.shape[0]
 
         h = self.h
-        h = self.h
 
         a = np.zeros(ne, dtype=np.float64)
 
@@ -354,7 +358,6 @@ class FLEBasis2D:
 
     def radialconv(self, a, f):
 
-
         a = a.flatten()
         b = self.radialconv_multipliers(f).flatten()
         if self.complexmode:
@@ -363,15 +366,14 @@ class FLEBasis2D:
             a_conv = self.c2r @ (b * (self.r2c @ a).flatten())
 
         return a_conv.flatten()
-    
-    
+
     def to_angular_order(self, a):
         a_ordered = np.zeros_like(a)
         blk_ind = self.blk_ind
         idx_list = self.idx_list
         for i in range(len(blk_ind) - 1):
             idx_i = idx_list[i]
-            a_ordered[blk_ind[i]:blk_ind[i + 1]] = a[idx_i]
+            a_ordered[blk_ind[i] : blk_ind[i + 1]] = a[idx_i]
 
         return a_ordered
 
@@ -381,35 +383,51 @@ class FLEBasis2D:
         idx_list = self.idx_list
         for i in range(len(blk_ind) - 1):
             idx_i = idx_list[i]
-            a[idx_i] = a_ordered[blk_ind[i]:blk_ind[i + 1]]
+            a[idx_i] = a_ordered[blk_ind[i] : blk_ind[i + 1]]
 
         return a
 
-
-    def expand_ctf(self, voltage_list, cs_list, alpha_list, defocus_list, pixel_size):
+    def expand_ctf(
+        self, voltage_list, cs_list, alpha_list, defocus_list, pixel_size
+    ):
         pts = self.pts
         h = self.h
-        wavelength_list = 12.2643247 / np.sqrt(voltage_list * 1e3 + 0.978466 * voltage_list ** 2)
-        c2_vec = (-np.pi * wavelength_list * defocus_list).reshape(-1,1)
-        c4_vec = (0.5 * np.pi * (cs_list * 1e7) * wavelength_list ** 3).reshape(-1,1)
+        wavelength_list = 12.2643247 / np.sqrt(
+            voltage_list * 1e3 + 0.978466 * voltage_list ** 2
+        )
+        c2_vec = (-np.pi * wavelength_list * defocus_list).reshape(-1, 1)
+        c4_vec = (0.5 * np.pi * (cs_list * 1e7) * wavelength_list ** 3).reshape(
+            -1, 1
+        )
 
         r2 = (pts * h / (pixel_size * 2 * np.pi)) ** 2
         r4 = r2 ** 2
         gamma = r2 @ c2_vec.T + r4 @ c4_vec.T
-        ctf_radial = np.sqrt(1 - alpha_list ** 2) * np.sin(gamma) - alpha_list * np.cos(gamma)
+        ctf_radial = np.sqrt(1 - alpha_list ** 2) * np.sin(
+            gamma
+        ) - alpha_list * np.cos(gamma)
 
+        rwts_mat = self.expand_raidal_vec(ctf_radial.T)
+
+        return rwts_mat
+
+    def expand_raidal_vec(self, radial_vec):
+
+        radial_vec = radial_vec.T
         if self.n_interp > self.n_radial:
-            ctf_radial = dct(ctf_radial, axis=0, type=2) / (2 * self.n_radial)
-            ctf_radial_z = np.zeros(ctf_radial.shape)
-            ctf_radial = np.concatenate((ctf_radial, ctf_radial_z), axis=0)
-            ctf_radial = idct(ctf_radial, axis=0, type=2) * 2 * ctf_radial.shape[0]
+            radial_vec = dct(radial_vec, axis=0, type=2) / (2 * self.n_radial)
+            radial_vec_z = np.zeros(radial_vec.shape)
+            radial_vec = np.concatenate((radial_vec, radial_vec_z), axis=0)
+            radial_vec = (
+                idct(radial_vec, axis=0, type=2) * 2 * radial_vec.shape[0]
+            )
 
-        rwts_mat = np.zeros((self.ne, len(voltage_list)), dtype=np.float64)
+        radial_fb = np.zeros((self.ne, radial_vec.shape[1]), dtype=np.float64)
 
         for i in range(self.ndmax + 1):
-            rwts_mat[self.idx_list[i], :] = self.A3[i] @ ctf_radial
+            radial_fb[self.idx_list[i], :] = self.A3[i] @ radial_vec
 
-        return rwts_mat.T
+        return radial_fb.T
 
     def rotate(self, a, theta):
 
@@ -441,52 +459,53 @@ class FLEBasis2D:
         # Step 3.
         wts = self.radialconv_wts(b)
 
-        b = wts / self.h**2
+        b = wts / self.h ** 2
 
         ne = self.ne
         return b.reshape(ne)
 
     def evaluate_t(self, f):
-        # warper for evaluate_t_helper
-
-        if np.prod(f.shape) == self.L**2:
-            a = self.evaluate_t_helper(f)
-        else:
-            N = f.shape[0]
-            if self.complexmode:
-                a = np.zeros((N, self.ne), dtype=np.complex128, order="C")
-            else:
-                a = np.zeros((N, self.ne), dtype=np.float64, order="C")
-            for i in range(N):
-                a[i, :] = self.evaluate_t_helper(f[i, :, :])
-
-        return a
-
-    def evaluate(self, a):
-
-        if np.prod(a.shape) == self.ne:
-            f = self.evaluate_helper(a)
-        else:
-            N = a.shape[0]
-            f = np.zeros((N, self.L, self.L), dtype=np.float64, order="C")
-            for i in range(N):
-                f[i, :, :] = self.evaluate_helper(a[i, :])
-
-        return f
-
-    def evaluate_t_helper(self, f):
         # see {sec:fast_details}
 
+        # DIMENSIONS BEFORE PADDING
+        L1 = self.L1
+        # DIMENSINOS AFTER PADDING
         L = self.L
-        f = np.copy(f).reshape(self.L, self.L)
 
-        # For small images just use matrix multiplication
-        if L < 16:
-            return (self.B.T @ f.flatten()).flatten()
+        if np.prod(f.shape) == self.L1 ** 2:
 
-        # Remove pixels outside disk
-        f[self.idx] = 0
-        f = f.flatten()
+            f = np.copy(f).reshape(self.L1, self.L1)
+
+            # ADD PADDING IF DIMENSIONS ODD
+            if L > L1:
+                f = np.pad(f,((0,1),(0,1)))
+
+            # For small images just use matrix multiplication
+            if L < 16:
+                return (self.B.T @ f.flatten()).flatten()
+
+            # Remove pixels outside disk
+            f[self.idx] = 0
+            f = f.flatten()
+
+        else:
+            nf = f.shape[0]
+            f = np.copy(f).reshape(nf, self.L1, self.L1)
+
+            # ADD PADDING IF DIMENESIONS ODD
+            if L > L1:
+                f = np.pad(f,((0,0),(0,1),(0,1)))
+
+            # For small images just use matrix multiplication
+            if L < 16:
+                return (self.B.T @ f.reshape(nf, L ** 2).T).T
+
+            # Remove pixels outside disk
+
+            # For small images just use matrix multiplication
+            # Remove pixels outside disk
+            f[:, self.idx] = 0
+            f = f.reshape(nf, L ** 2)
 
         # Step 1. {sec:fast_details}
         z = self.step1(f)
@@ -498,21 +517,41 @@ class FLEBasis2D:
         a = self.step3(b)
 
         if self.complexmode:
-            a = self.r2c @ a.flatten()
 
-        return a.reshape(self.ne)
+                # see {eq:eigenfun} and {eq:eigenfun_extend}
+            if np.prod(f.shape) == self.L ** 2:
+                a = self.r2c @ a.flatten()
+                a = a.reshape(self.ne)
 
-    def evaluate_helper(self, a):
+            else:
+                a = (self.r2c @ a.T).T
+
+        return a
+
+    def evaluate(self, a):
         # see {rmk:how_to_apply_B} and {sec:fast_details}
 
-        if self.complexmode:
-            a = np.real(self.c2r @ a.flatten())
-        a = np.real(a)
+        L = self.L
 
-        a = a.reshape(self.ne)
-        # for small images use matrix multiplication
-        if self.L < 16:
-            return (self.B @ a).reshape(self.L, self.L)
+        if np.prod(a.shape) == self.ne:
+
+            if self.complexmode:
+                a = np.real(self.c2r @ a.flatten())
+                a = a.reshape(self.ne)
+
+            a = np.real(a)
+            # for small images use matrix multiplication
+            if self.L < 16:
+                return (self.B @ a).reshape(self.L, self.L)
+
+        else:
+            na = a.shape[0]
+            if self.complexmode:
+                a = (self.c2r @ a.T).T
+
+            a = np.real(a)
+            if self.L < 16:
+                return (self.B @ a.T).reshape(na, self.L, self.L)
 
         # B1
         b = self.step3_H(a)
@@ -523,8 +562,21 @@ class FLEBasis2D:
         # B3
         f = self.step1_H(z)
 
-        L = self.L
-        return f.reshape(L, L)
+        if np.prod(a.shape) == self.ne:
+            f = f.reshape(L, L)
+
+            # REMOVE PADDING
+            if self.L > self.L1:
+                f = f[:self.L1,:self.L1]
+        else:
+            na = a.shape[0]
+            f = f.reshape(na, L, L)
+
+            # REMOVE PADDING
+            if self.L > self.L1:
+                f = f[:,:self.L1,:self.L1]
+
+        return f
 
     def expand(self, f):
 
@@ -536,100 +588,228 @@ class FLEBasis2D:
 
     def step1(self, f):
 
-        f = f.reshape(self.L, self.L)
-        f = np.array(f, dtype=np.complex128)
-        z = np.zeros((self.n_radial, self.n_angular), dtype=np.complex128)
-        z0 = self.plan2.execute(f) * self.h**2
-        z0 = z0.reshape(self.n_radial, self.n_angular // 2)
-        z[:, : self.n_angular // 2] = z0
-        z[:, self.n_angular // 2 :] = np.conj(z0)
-        z = z.flatten()
+        if np.prod(f.shape) == self.L ** 2:
+            f = f.reshape(self.L, self.L)
+            f = np.array(f, dtype=np.complex128)
+            z = np.zeros((self.n_radial, self.n_angular), dtype=np.complex128)
+            z0 = self.plan2.execute(f) * self.h ** 2
+            z0 = z0.reshape(self.n_radial, self.n_angular // 2)
+            z[:, : self.n_angular // 2] = z0
+            z[:, self.n_angular // 2 :] = np.conj(z0)
+            z = z.flatten()
+        else:
+
+            L = self.L
+            nf = f.shape[0]
+            f = f.reshape(nf, L, L)
+            f = np.array(f, dtype=np.complex128)
+
+            z = np.zeros(
+                (nf, self.n_radial, self.n_angular), dtype=np.complex128
+            )
+            nufft_type = 2
+            plan2v = finufft.Plan(nufft_type, (L, L), n_trans=nf, eps=self.eps)
+            plan2v.setpts(self.grid_x, self.grid_y)
+
+            z0 = plan2v.execute(f) * self.h ** 2
+            z0 = z0.reshape(nf, self.n_radial, self.n_angular // 2)
+
+            z[:, :, : self.n_angular // 2] = z0
+            z[:, :, self.n_angular // 2 :] = np.conj(z0)
+            z = z.reshape(nf, self.n_angular * self.n_radial)
 
         return z
 
     def step1_H(self, z):
 
-        # Half z
-        z = z[:, : self.n_angular // 2]
-        f = self.plan1.execute(z.flatten())
-        f = f + np.conj(f)
-        f = np.real(f)
-        f = f.reshape(self.L, self.L)
-        f[self.idx] = 0
+        if np.prod(z.shape) == self.n_radial * self.n_angular:
 
-        return f.flatten()
+            # Half z
+            z = z[:, : self.n_angular // 2]
+            f = self.plan1.execute(z.flatten())
+            f = f + np.conj(f)
+            f = np.real(f)
+            f = f.reshape(self.L, self.L)
+            f[self.idx] = 0
+
+            f = f.flatten()
+
+        else:
+
+            nz = z.shape[0]
+            z = z[:, :, : self.n_angular // 2]
+            nufft_type = 1
+            plan1v = finufft.Plan(
+                nufft_type, (self.L, self.L), n_trans=nz, eps=self.eps
+            )
+            plan1v.setpts(self.grid_x, self.grid_y)
+            f = plan1v.execute(z.reshape(nz, -1))
+            f = f + np.conj(f)
+            f = np.real(f)
+            f = f.reshape(nz, self.L, self.L)
+            f[:, self.idx] = 0
+
+        return f
 
     def step2(self, z):
 
-        # Compute Fourier coefficients along rings
-        z = z.reshape(self.n_radial, self.n_angular)
-        b = np.fft.fft(z, n=self.n_angular, axis=1) / self.n_angular
-        b = b[:, self.nus]
-        b = np.conj(b).T
-        b = self.c2r_nus @ b
-        b = np.real(b).T
+        if np.prod(z.shape) == self.n_radial * self.n_angular:
+            # Compute Fourier coefficients along rings
+            z = z.reshape(self.n_radial, self.n_angular)
+            b = np.fft.fft(z, n=self.n_angular, axis=1) / self.n_angular
+            b = b[:, self.nus]
+            b = np.conj(b).T
+            b = self.c2r_nus @ b
+            b = np.real(b).T
+
+        else:
+
+            nz = z.shape[0]
+            ind_vec = self.ind_vec
+            z = z.reshape(nz, self.n_radial, self.n_angular)
+            b = np.fft.fft(z, n=self.n_angular, axis=2) / self.n_angular
+            b = b[:, :, self.nus]
+            b = np.conj(b)
+
+            b = np.swapaxes(b, 0, 2)
+            b = b.reshape(-1, self.n_radial * nz)
+            b = self.c2r_nus @ b
+            b = b.reshape(-1, self.n_radial, nz)
+            b = np.real(np.swapaxes(b, 0, 2))
 
         return b
 
     def step3(self, b):
 
-        b = np.array(b, order="F")
-        if self.n_interp > self.n_radial:
-            b = dct(b, axis=0, type=2) / (2 * self.n_radial)
-            bz = np.zeros(b.shape)
-            b = np.concatenate((b, bz), axis=0)
-            b = idct(b, axis=0, type=2)*2*b.shape[0]
+        if len(b.shape) == 2:
 
-        h = self.h
+            b = np.array(b, order="F")
+            if self.n_interp > self.n_radial:
+                b = dct(b, axis=0, type=2) / (2 * self.n_radial)
+                bz = np.zeros(b.shape)
+                b = np.concatenate((b, bz), axis=0)
+                b = idct(b, axis=0, type=2) * 2 * b.shape[0]
 
-        a = np.zeros(self.ne, dtype=np.float64)
-        y = [None] * (self.ndmax + 1)
+            h = self.h
 
-        for i in range(self.ndmax + 1):
-            y[i] = (self.A3[i] @ b[:, i]).flatten()
+            a = np.zeros(self.ne, dtype=np.float64)
+            y = [None] * (self.ndmax + 1)
 
-        for i in range(self.ndmax + 1):
-            a[self.idx_list[i]] = y[i]
+            for i in range(self.ndmax + 1):
+                y[i] = (self.A3[i] @ b[:, i]).flatten()
 
-        a = a * self.cs / h
+            for i in range(self.ndmax + 1):
+                a[self.idx_list[i]] = y[i]
 
-        return a.flatten()
+            a = a * self.cs / h
+            a = a.flatten()
+
+        else:
+
+            nb = b.shape[0]
+
+            if self.n_interp > self.n_radial:
+                b = dct(b, axis=1, type=2) / (2 * self.n_radial)
+                bz = np.zeros(b.shape)
+                b = np.concatenate((b, bz), axis=1)
+                b = idct(b, axis=1, type=2) * 2 * b.shape[1]
+
+            h = self.h
+
+            b = np.moveaxis(b, 0, -1)
+
+            a = np.zeros((self.ne, nb), dtype=np.float64)
+            for i in range(self.ndmax + 1):
+                a[self.idx_list[i]] = self.A3[i] @ b[:, i, :]
+
+            a = a.T
+
+            a = a * self.cs / h
+
+        return a
 
     def step3_H(self, a):
 
-        h = self.h
+        if np.prod(a.shape) == self.ne:
 
-        a = a * h
-        a = a.flatten()
-        a = a * self.cs
+            h = self.h
 
-        y = [None] * (self.ndmax + 1)
-        for i in range(self.ndmax + 1):
-            y[i] = a[self.idx_list[i]]
+            a = a * h
+            a = a.flatten()
+            a = a * self.cs
 
-        b = np.zeros(
-            (self.n_interp, 2 * self.nmax + 1), dtype=np.float64, order="F"
-        )
-        for i in range(self.ndmax + 1):
-            b[:, i] = self.A3_T[i] @ y[i]
+            y = [None] * (self.ndmax + 1)
+            for i in range(self.ndmax + 1):
+                y[i] = a[self.idx_list[i]]
 
-        if self.n_interp > self.n_radial:
-            b = dct(b, axis=0, type=2)
-            b = b[: self.n_radial, :]
-            b = idct(b, axis=0, type=2) 
+            b = np.zeros(
+                (self.n_interp, 2 * self.nmax + 1), dtype=np.float64, order="F"
+            )
+            for i in range(self.ndmax + 1):
+                b[:, i] = self.A3_T[i] @ y[i]
+
+            if self.n_interp > self.n_radial:
+                b = dct(b, axis=0, type=2)
+                b = b[: self.n_radial, :]
+                b = idct(b, axis=0, type=2)
+
+        else:
+
+            na = a.shape[0]
+
+            a = a.reshape(na, self.ne)
+            # for small images use matrix multiplication
+
+            h = self.h
+
+            a = a * h * self.cs
+
+            a = a.T
+            b = np.zeros(
+                (self.n_interp, 2 * self.nmax + 1, na),
+                dtype=np.float64,
+                order="F",
+            )
+            for i in range(self.ndmax + 1):
+                b[:, i, :] = self.A3_T[i] @ a[self.idx_list[i]]
+
+            b = np.moveaxis(b, -1, 0)
+
+            if self.n_interp > self.n_radial:
+                b = dct(b, axis=1, type=2)
+                b = b[:, : self.n_radial, :]
+                b = idct(b, axis=1, type=2)
 
         return b
 
     def step2_H(self, b):
 
-        tmp = np.zeros((b.shape[0], self.n_angular), dtype=np.complex128)
-        tmp0 = (self.r2c_nus @ b.T).T
-        tmp[:, self.nus] = np.conj(tmp0)
-        z = np.fft.ifft(tmp, axis=1)
+        if len(b.shape) == 2:
+
+            tmp = np.zeros((b.shape[0], self.n_angular), dtype=np.complex128)
+            tmp0 = (self.r2c_nus @ b.T).T
+            tmp[:, self.nus] = np.conj(tmp0)
+            z = np.fft.ifft(tmp, axis=1)
+
+        else:
+
+            nb = b.shape[0]
+            tmp = np.zeros(
+                (b.shape[0], b.shape[1], self.n_angular), dtype=np.complex128
+            )
+
+            b = np.swapaxes(b, 0, 2)
+            b = b.reshape(-1, self.n_radial * nb)
+            b = self.r2c_nus @ b
+            b = b.reshape(-1, self.n_radial, nb)
+            b = np.swapaxes(b, 0, 2)
+
+            tmp[:, :, self.nus] = np.conj(b)
+            z = np.fft.ifft(tmp, axis=2)
 
         return z
 
-    def create_denseB(self,numthread=1):
+    def create_denseB(self, numthread=1):
         # see {eq:operator_B} and {eq:operator_B^*}
 
         # Evaluate eigenfunctions
@@ -640,7 +820,7 @@ class FLEBasis2D:
         xs, ys = np.meshgrid(x, y)
         xs = xs / R
         ys = ys / R
-        rs = np.sqrt(xs**2 + ys**2)
+        rs = np.sqrt(xs ** 2 + ys ** 2)
         ts = np.arctan2(ys, xs)
 
         # Compute in parallel if numthread > 1
@@ -663,10 +843,15 @@ class FLEBasis2D:
                 B_par[:, :, i] = B_list[i]
             B = h * B_par
 
-        B = B.reshape(self.L**2, self.ne)
+        # REMOVE ODD PADDING
+        if self.L > self.L1:
+            B = B[:self.L1,:self.L1,:]
+
+        B = B.reshape(self.L1 ** 2, self.ne)
         B = self.transform_complex_to_real(np.conj(B), self.ns)
 
-        return B.reshape(self.L**2, self.ne)
+
+        return B.reshape(self.L1 ** 2, self.ne)
 
     def lap_eig_disk(self, ne, bandlimit, max_bandlimit):
 
@@ -682,7 +867,7 @@ class FLEBasis2D:
 
         # load table of roots of jn (the scipy code has an issue where it gets
         # stuck in an infinite loop in Newton's method as of Jun 2022)
-        path_to_module = os.path.dirname(__file__) 
+        path_to_module = os.path.dirname(__file__)
         zeros_path = os.path.join(path_to_module, "jn_zeros_n=3000_nt=2500.mat")
         data = loadmat(zeros_path)
         roots_table = data["roots_table"]
@@ -757,18 +942,14 @@ class FLEBasis2D:
             n = ns[i]
             lmd = lmds[i]
             # see {eq:eigenfun_const}
-            c = 1 / np.sqrt(0.5 * np.pi * spl.jv(ns[i] + 1, lmds[i]) ** 2)
+            c = 1 / np.sqrt(np.pi * spl.jv(ns[i] + 1, lmds[i]) ** 2)
             if ns[i] == 0:
-                c /= np.sqrt(2)
-                # see {eq:eigenfun} and {eq:eigenfun_extend}
                 psi[i] = (
                     lambda r, t, n=n, c=c, lmd=lmd: c
                     * spl.jv(n, lmd * r)
                     * (r <= 1)
                 )
             else:
-                # see {eq:eigenfun_const}
-                c = c / np.sqrt(2)
                 # see {eq:eigenfun} and {eq:eigenfun_extend}
                 psi[i] = (
                     lambda r, t, c=c, n=n, lmd=lmd: c
@@ -879,9 +1060,9 @@ class FLEBasis2D:
         a[k + 1 :] = 0
         return a
 
-#############################################################################
-#   Interpolation
-#############################################################################
+    #############################################################################
+    #   Interpolation
+    #############################################################################
 
     def barycentric_interp_sparse(self, x, xs, ys, s):
         # https://people.maths.ox.ac.uk/trefethen/barycentric.pdf
@@ -976,5 +1157,3 @@ class FLEBasis2D:
             I[j] = True
 
         return ws
-
-
